@@ -2,8 +2,8 @@
 
 ;; Copyright (C) 2013-2025 Skye Shaw and others
 ;; Author: Skye Shaw <skye.shaw@gmail.com>
-;; Package-Version: 20251023.2008
-;; Package-Revision: 67b02cf0df4e
+;; Package-Version: 20251116.105
+;; Package-Revision: 12caebc0982d
 ;; Keywords: git, vc, github, bitbucket, gitlab, sourcehut, aws, azure, convenience
 ;; URL: http://github.com/sshaw/git-link
 ;; Package-Requires: ((emacs "24.3"))
@@ -251,7 +251,8 @@ See its docs."
     ("googlesource.com" git-link-googlesource)
     ("visualstudio\\|azure" git-link-azure)
     ("sourcegraph" git-link-sourcegraph)
-    ("\\(amazonaws\\|amazon\\)\\.com" git-link-codecommit))
+    ("\\(amazonaws\\|amazon\\)\\.com" git-link-codecommit)
+    ("forge.fedoraproject.org" git-link-codeberg))
   "Alist of host names and functions creating file links for those.
 Each element looks like (REGEXP FUNCTION) where REGEXP is used to
 match the remote's host name and FUNCTION is used to generate a link
@@ -273,7 +274,8 @@ As an example, \"gitlab\" will match with both \"gitlab.com\" and
     ("googlesource.com" git-link-commit-googlesource)
     ("visualstudio\\|azure" git-link-commit-azure)
     ("sourcegraph" git-link-commit-sourcegraph)
-    ("\\(amazonaws\\|amazon\\)\\.com" git-link-commit-codecommit))
+    ("\\(amazonaws\\|amazon\\)\\.com" git-link-commit-codecommit)
+    ("forge.fedoraproject.org" git-link-commit-codeberg))
   "Alist of host names and functions creating commit links for those.
 Each element looks like (REGEXP FUNCTION) where REGEXP is used to
 match the remote's host name and FUNCTION is used to generate a link
@@ -294,7 +296,8 @@ As an example, \"gitlab\" will match with both \"gitlab.com\" and
     ("googlesource.com" git-link-homepage-github)
     ("visualstudio\\|azure" git-link-homepage-github)
     ("sourcegraph" git-link-homepage-github)
-    ("\\(amazonaws\\|amazon\\)\\.com" git-link-homepage-codecommit))
+    ("\\(amazonaws\\|amazon\\)\\.com" git-link-homepage-codecommit)
+    ("forge.fedoraproject.org" git-link-homepage-codeberg))
   "Alist of host names and functions creating homepage links for those.
 Each element looks like (REGEXP FUNCTION) where REGEXP is used to
 match the remote's host name and FUNCTION is used to generate a link
@@ -833,6 +836,9 @@ is prepended to it."
 (defun git-link-homepage-codecommit (hostname dirname)
   (format "%s/%s/browse" hostname dirname))
 
+(defun git-link-homepage-codeberg (hostname dirname)
+  (format "%s/%s" hostname dirname))
+
 (define-obsolete-function-alias
   'git-link-homepage-svannah 'git-link-homepage-savannah "cf947f9")
 
